summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderimap.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/kmfolderimap.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfolderimap.h')
-rw-r--r--kmail/kmfolderimap.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/kmail/kmfolderimap.h b/kmail/kmfolderimap.h
index 2f85685b..f303325b 100644
--- a/kmail/kmfolderimap.h
+++ b/kmail/kmfolderimap.h
@@ -61,15 +61,15 @@ using KPIM::ProgressItem;
class KMMsgMetaData
{
public:
- KMMsgMetaData(KMMsgStatus aStatus)
- :mStatus(aStatus), mSerNum(0) {}
- KMMsgMetaData(KMMsgStatus aStatus, TQ_UINT32 aSerNum)
- :mStatus(aStatus), mSerNum(aSerNum) {}
+ KMMsgMetaData(KMMsgtqStatus atqStatus)
+ :mtqStatus(atqStatus), mSerNum(0) {}
+ KMMsgMetaData(KMMsgtqStatus atqStatus, TQ_UINT32 aSerNum)
+ :mtqStatus(atqStatus), mSerNum(aSerNum) {}
~KMMsgMetaData() {};
- KMMsgStatus status() const { return mStatus; }
+ KMMsgtqStatus status() const { return mtqStatus; }
TQ_UINT32 serNum() const { return mSerNum; }
private:
- KMMsgStatus mStatus;
+ KMMsgtqStatus mtqStatus;
TQ_UINT32 mSerNum;
};
@@ -78,6 +78,7 @@ private:
class KMFolderImap : public KMFolderMbox
{
Q_OBJECT
+ TQ_OBJECT
friend class ::KMail::ImapJob;
public:
@@ -98,8 +99,8 @@ public:
virtual imapState getSubfolderState() { return mSubfolderState; }
virtual void setSubfolderState(imapState state);
- /** Usually a parent is given. But in some cases there is no
- fitting parent object available. Then the name of the folder
+ /** Usually a tqparent is given. But in some cases there is no
+ fitting tqparent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderImap(KMFolder* folder, const char* name=0);
virtual ~KMFolderImap();
@@ -167,11 +168,11 @@ public:
* Create a new subfolder
* You may specify the root imap path or this folder will be used
* If you set askUser to false and the server can only handle folders
- * that contain messages _or_ folders the new folder is set to "tqcontains messages"
+ * that contain messages _or_ folders the new folder is set to "contains messages"
* by default
*/
void createFolder(const TQString &name,
- const TQString& imapPath = TQString::null, bool askUser = true);
+ const TQString& imapPath = TQString(), bool askUser = true);
/**
* Delete a message
@@ -183,12 +184,12 @@ public:
* Change the status of the message indicated by @p index
* Overloaded function for the following one
*/
- virtual void seStatus(int idx, KMMsgStatus status, bool toggle);
+ virtual void setqStatus(int idx, KMMsgtqStatus status, bool toggle);
/**
* Change the status of several messages indicated by @p ids
*/
- virtual void seStatus(TQValueList<int>& _ids, KMMsgStatus status, bool toggle);
+ virtual void setqStatus(TQValueList<int>& _ids, KMMsgtqStatus status, bool toggle);
/** generates sets of uids */
static TQStringList makeSets( TQValueList<ulong>&, bool sort = true);
@@ -240,7 +241,7 @@ public:
/**
* Convert message status to a list of IMAP flags
*/
- static TQString statusToFlags(KMMsgStatus status, int supportedFalgs);
+ static TQString statusToFlags(KMMsgtqStatus status, int supportedFalgs);
/**
* Return the filename of the folder (reimplemented from KFolder)
@@ -289,7 +290,7 @@ public:
/**
* Mark the folder as already removed from the server
* If set to true the folder will only be deleted locally
- * This will recursively be applied to all children
+ * This will recursively be applied to all tqchildren
*/
void setAlreadyRemoved(bool removed);
@@ -320,7 +321,7 @@ public:
virtual bool isMoveable() const;
/** Initialize this storage from another one. Used when creating a child folder */
- void initializeFrom( KMFolderImap* parent, TQString path, TQString mimeType );
+ void initializeFrom( KMFolderImap* tqparent, TQString path, TQString mimeType );
/** Returns the IMAP flags that can be stored on the server. */
int permanentFlags() const { return mPermanentFlags; }
@@ -362,7 +363,7 @@ public slots:
virtual int addMsg(TQPtrList<KMMessage>&, TQValueList<int>& index_return);
/** Copy the messages to this folder */
- void copyMsg(TQPtrList<KMMessage>& msgList/*, KMFolder* parent*/);
+ void copyMsg(TQPtrList<KMMessage>& msgList/*, KMFolder* tqparent*/);
/** Detach message from this folder. Usable to call addMsg() afterwards.
@@ -379,13 +380,13 @@ public slots:
* Convert IMAP flags to a message status
* @param newMsg specifies whether unseen messages are new or unread
*/
- static void flagsToStatus(KMMsgBase *msg, int flags, bool newMsg = TRUE, int supportedFalgs = 31 );
+ static void flagsTotqStatus(KMMsgBase *msg, int flags, bool newMsg = TRUE, int supportedFalgs = 31 );
/**
* Convert IMAP seen flag to a message status.
* @param newMsg specifies whether unseen messages are new or unread
*/
- static void seenFlagToStatus( KMMsgBase *msg, int flags, bool newMsg = true );
+ static void seenFlagTotqStatus( KMMsgBase *msg, int flags, bool newMsg = true );
/**
* Connected to the result signal of the copy/move job
@@ -437,7 +438,7 @@ protected:
/** Create or find the INBOX and initialize it */
void initInbox();
/** See if there is a better parent then this folder */
KMFolderImap* findParent( const TQString& path, const TQString& name );
/** See if all folders are still present on server, otherwise delete them */
@@ -456,7 +457,7 @@ protected slots:
/**
* Get the folder now (internal)
*/
- void reallyGetFolder(const TQString &startUid = TQString::null);
+ void reallyGetFolder(const TQString &startUid = TQString());
/**
* For listing the contents of a folder
@@ -437,7 +438,7 @@ protected:
/** Create or find the INBOX and initialize it */
void initInbox();
- /** See if there is a better parent then this folder */
+ /** See if there is a better tqparent then this folder */
KMFolderImap* findParent( const TQString& path, const TQString& name );
/** See if all folders are still present on server, otherwise delete them */